@@ -6,5 +6,5 @@
 # @Contact : xzregg@gmail.com
 # @Desc    : 
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
