@@ -8,33 +8,35 @@
 import base64
 import datetime
 import time
-from functools import reduce
 
 import passlib.hash
 from django.contrib.auth.models import AbstractBaseUser
 from django.db import models
-from django.db.models.signals import post_delete
-from django.dispatch import receiver
 from django.utils.translation import gettext_lazy as _
 
-from framework.models import BaseModel
+from framework.models import BaseModel, JSONField
 from framework.utils.cache import CacheAttribute
 from framework.utils.myenum import Enum
 from framework.validators import LetterValidator
 from .resource import Resource, ResourceProxy
 from .role import Role
-
+from ..apps import MyadminConfig
+from framework.utils.log import logger
 
 class UserManagerMixin(object):
     """用户管理者,扩展admin模型的方法
     """
 
     def __init__(self, *args, **kwargs):
-        self.resource = ResourceProxy(self)
+        # self.resource = ResourceProxy(self)
         super(UserManagerMixin, self).__init__(*args, **kwargs)
         self.__resource_map = {}
         self.__cache_roles = None
 
+    @property
+    def resource(self) -> Resource:
+        return ResourceProxy(self)
+
     def get_role_index(self):
         for r in self.get_roles():
             if r.index:
@@ -52,7 +54,7 @@ class UserManagerMixin(object):
         """
         return cls.objects.filter(id=user_id).prefetch_related('role').first()
 
-    def _check_role(self, name):
+    def check_role(self, name):
         for r in self.get_roles():
             if r.name == name:
                 return True
@@ -62,16 +64,15 @@ class UserManagerMixin(object):
     def is_root(self):
         """是否超级管理员
         """
-
-        return self._check_role('root')
+        return self.check_role('root')
 
     @CacheAttribute
     def is_sdk_manager(self):
-        return self._check_role('sdk_manager')
+        return self.check_role('sdk_manager')
 
     @CacheAttribute
     def is_yunying(self):
-        return self._check_role('yunying')
+        return self.check_role('yunying')
 
     @property
     def is_agent(self):
@@ -87,7 +88,7 @@ class UserManagerMixin(object):
     def is_kefu(self):
         """是否客服
         """
-        return self._check_role('kefu')
+        return self.check_role('kefu')
 
     @property
     def is_not_active(self):
@@ -97,7 +98,7 @@ class UserManagerMixin(object):
     def is_manager(self):
         """是否管理员
         """
-        return self.is_root or self.get_manageable_user().exists()
+        return self.is_root or self.check_role('manager') or self.get_manageable_user().exists()
 
     def get_manageable_user(self):
         """获取自己的下属,除权限集合 如果是管理员这不能获取到
@@ -114,7 +115,6 @@ class UserManagerMixin(object):
             new_attrs = list((input_list & resource_attrs))
         else:
             new_attrs = list((input_list & resource_attrs) or resource_attrs)
-
         return new_attrs
 
     def get_resource_ids(self, name, input_list=None):
@@ -126,6 +126,8 @@ class UserManagerMixin(object):
         self.__resource_map[name] = query_set
 
     def get_resource(self, name):
+        """按资源名获取所属角色相应的资源
+        """
         _r = self.__resource_map.get(name, None)
         if _r == None:
             _r = self._get_resource(name)
@@ -133,47 +135,9 @@ class UserManagerMixin(object):
         return self.__resource_map[name]
 
     def _get_resource(self, name):
+        return Resource.get_model_resource(name).get_resource_queryset(self)
 
-        model_resource = Resource.get_model_resource(name)
-        if hasattr(model_resource, 'get_resource_queryset'):
-            get_resource_queryset_method = getattr(model_resource, 'get_resource_queryset')
-            return get_resource_queryset_method(self)
-        return self.get_resource_queryset_from_name(name)
-
-    def get_resource_queryset_from_name(self, name):
-        """按资源名获取所属角色相应的资源
-        """
-        model_resource = Resource.get_model_resource(name)
-
-        ResourceClass = model_resource.model_class
-        if self.is_root:
-            return ResourceClass.objects.all()
-        resource_objs = self.get_resource_obj().filter(name=name)
-        try:
-            if len(resource_objs) == 1:
-                resource_ids = resource_objs[0].members
-            else:
-                resource_ids = reduce(lambda x, y: y | x, resource_objs)
-        except TypeError as e:
-            resource_ids = []
-
-        query = {'%s__in' % model_resource.unique_filed_name: resource_ids}
-
-        return ResourceClass.objects.filter(**query).distinct()
-
-    _get_resource_from_model = get_resource_queryset_from_name
-
-    def get_resource_obj(self):
-        """获取资源对象,超级管理拥有所有资源对象
-        """
-        if self.is_root:
-            return Resource.objects.all()
-        else:
-            return Resource.objects.filter(role__in=self.get_roles())
-
-    def get_resource_bitmap(self, name):
-        # todo 使用位操作检查权限
-        self.get_resource_obj().filter(name=name)
+    _get_resource_from_model = _get_resource
 
     def get_roles(self):
         """获取角色
@@ -201,8 +165,8 @@ class UserManagerMixin(object):
         user.status = cls.Status.NORMAL
         user.set_password('123456')
         user.save()
-        print(user.role.all())
-        print('创建相关角色后,请务必删除root账户!')
+
+        logger.info('创建相关角色后,请务必删除root账户!')
         return user
 
 
@@ -224,6 +188,7 @@ class User(BaseModel, AbstractBaseUser, UserManagerMixin):
         NORMAL = (0, _('正常'))  # 正常用户
         CHANNEL = (1, _('渠道'))  # 渠道用户
 
+    is_staff = False
     role = models.ManyToManyField(Role, verbose_name=_('所属角色'), blank=True)
     alias = models.CharField(_('别名'), max_length=50, db_index=True)
 
@@ -237,6 +202,7 @@ class User(BaseModel, AbstractBaseUser, UserManagerMixin):
     session_key = models.CharField(_('会话key'), max_length=40, db_index=True, default='', blank=True, null=False)
 
     class Meta:
+        app_label = MyadminConfig.name
         ordering = ['id']
 
     # # @property
@@ -325,6 +291,32 @@ class User(BaseModel, AbstractBaseUser, UserManagerMixin):
         the_user.session_key = request.session.session_key
         the_user.save()
 
+    @property
+    def is_ldap(self):
+        return hasattr(self, 'ldap_attr_map')
+
+    @CacheAttribute
+    def user_info(self):
+        user_info = None
+        if self.id:
+            user_infos = self.userinfo_set.all()
+            if len(user_infos) >= 1:
+                user_info = user_infos[0]
+            else:
+                user_info, _ = self.userinfo_set.get_or_create()
+        return user_info
+
+    @property
+    def email(self):
+        if self.user_info:
+            return self.user_info.email
+
+    @email.setter
+    def email(self, emial):
+        if self.user_info:
+            self.user_info.email = emial
+            self.user_info.save()
+
 
 class UserInfo(BaseModel):
     """管理员信息
@@ -349,32 +341,20 @@ class UserInfo(BaseModel):
         return self.user.alias
 
     class Meta:
-        pass
+        app_label = MyadminConfig.name
 
 
 class UserOauth(BaseModel):
     """第三方登录关联表
     """
-    user_id = models.IntegerField('管理员ID', default=0, db_index=True)
-    oauth_type = models.CharField('Oauth类型', max_length=20)
-    oauth_id = models.CharField('Oauth 账号ID', max_length=128, db_index=True)
-    access_token = models.CharField('access_token', max_length=512)
-    expires_timestamp = models.IntegerField('过期时间戳', default=time.time)
+    user = models.ForeignKey(User, on_delete=models.CASCADE, verbose_name=_('所属管理员'), null=True)
+    oauth_type = models.CharField(verbose_name=_('Oauth类型'), max_length=20)
+    oauth_id = models.CharField(verbose_name=_('Oauth 账号ID'), max_length=128, db_index=True)
+    access_token = models.CharField(verbose_name=_('access_token'), max_length=512)
+    expires_timestamp = models.IntegerField(verbose_name=_('过期时间戳'), default=time.time)
 
-    other_info = models.TextField('其他信息', default='{}')
+    other_info = JSONField(verbose_name=_('其他信息'), default='{}')
 
     class Meta:
-        pass
+        app_label = MyadminConfig.name
         # db_table = u'user_oauth'
-
-
-@receiver(post_delete, sender=User)
-def user_delete_handler(sender, **kwargs):
-    """
-    管理员删除信号
-    :param sender:
-    :param kwargs:
-    :return:
-    """
-    user_id = kwargs['instance'].id
-    UserOauth.objects.filter(user_id=user_id).delete()
