@@ -10,6 +10,7 @@
 # SECURITY WARNING: don't run with debug turned on in production!
 
 import logging
+import os
 
 DEBUG = False
 
@@ -29,7 +30,7 @@ DATABASES = {
 
                 'PORT'    : '3306',
 
-                'OPTIONS' : {'isolation_level': None}
+                'OPTIONS' : {'isolation_level': None, 'charset': 'utf8mb4'}
         },
         'read'   : {
 
@@ -41,7 +42,7 @@ DATABASES = {
                 'HOST'    : '10.19.200.185',
 
                 'PORT'    : '3306',
-                'OPTIONS' : {'isolation_level': None}
+                'OPTIONS' : {'isolation_level': None, 'charset': 'utf8mb4'}
         },
         'write'  : {
 
@@ -51,7 +52,7 @@ DATABASES = {
                 'PASSWORD': '123456',
                 'HOST'    : '10.19.200.185',
                 'PORT'    : '3306',
-                'OPTIONS' : {'isolation_level': None}
+                'OPTIONS' : {'isolation_level': None, 'charset': 'utf8mb4'}
 
         }
 
@@ -71,3 +72,23 @@ DATABASES['db'] = DATABASES['default']
 #         }
 #     }
 # }
+
+CELERY_BROKER_URL = 'redis://:123456@h29:6379/1'
+
+CHANNEL_LAYERS = {
+        "default": {
+                "BACKEND": "channels_redis.core.RedisChannelLayer",
+                "CONFIG" : {
+                        "hosts": ["redis://:123456@h29:6379/2"],
+                },
+        },
+}
+
+
+SETTINGS_LOADER_ETCD = dict(host='localhost', port=2379,
+                             ca_cert=None, cert_key=None, cert_cert=None, timeout=None,
+                             user=None, password=None, grpc_options=None,
+                             prefix_key=os.environ.get('DJANGO_ENV', 'dev'))
+
+SETTINGS_LOADER_REDIS = dict(url='redis://:123456@127.0.0.1:6379/5', decode_responses=True, socket_connect_timeout=3,
+                              prefix_key=os.environ.get('DJANGO_ENV', 'dev'))
\ No newline at end of file
