@@ -5,6 +5,7 @@ import json
 import re
 from collections import OrderedDict
 
+import timezone_field
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.management.color import no_style
@@ -14,7 +15,7 @@ from django.urls import reverse
 from django.utils.encoding import force_bytes
 from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
-from rest_framework.fields import DictField
+from rest_framework.fields import DictField, CharField
 
 from .utils import json_dumps, ObjectDict, trace_msg
 from .utils.cache import CachedClassAttribute
@@ -262,21 +263,11 @@ class SqlModelMixin(object):
         return cls._meta.db_table
 
 
-class BaseModel(models.Model, SqlModelMixin):
+class BaseModelMixin(SqlModelMixin):
     """
     基本模型
     """
 
-    id = models.BigAutoField(primary_key=True)
-    _version = models.IntegerField(_("版本"), default=0, null=False)
-    # auto_now_add = True    #创建时添加的时间  修改数据时，不会发生改变
-    create_datetime = models.DateTimeField(_("创建时间"), auto_now_add=True,blank=True)
-    update_datetime = models.DateTimeField(_("更新时间"), auto_now=True,blank=True)
-
-    class Meta:
-        abstract = True
-        ordering = ['id']
-
     def is_related_field(self, field):
         return isinstance(field, (models.ForeignKey, models.ManyToManyField, models.OneToOneRel))
 
@@ -354,24 +345,24 @@ class BaseModel(models.Model, SqlModelMixin):
             assert value != None and value != '', '%s 不能为空!' % self.get_verbose_name(name)
         setattr(self, name, value)
 
-    def to_dict(self, ignore_list=(),has_m2mfields=False,is_msgpack=False):
+    def to_dict(self, ignore_list=(), has_m2mfields=False, is_msgpack=False):
         d = {}
         for field in self._meta.fields:
             attr = field.name
             attr_value = getattr(self, attr)
 
-                # 特殊处理datetime的数据
+            # 特殊处理datetime的数据
             if isinstance(attr_value, datetime.datetime) and is_msgpack:
                 d[attr] = attr_value.strftime('%Y-%m-%d %H:%M:%S')
             elif isinstance(attr_value, datetime.date):
                 d[attr] = attr_value.strftime('%Y-%m-%d') and is_msgpack
             # 递归生成BaseModel类的dict
             elif isinstance(attr_value, BaseModel):
-                d[attr] = attr_value.get_dict(has_m2mfields=has_m2mfields,is_msgpack=is_msgpack)
-            elif isinstance(attr_value, (int,str,float)):
+                d[attr] = attr_value.get_dict(has_m2mfields=has_m2mfields, is_msgpack=is_msgpack)
+            elif isinstance(attr_value, (int, str, float)):
                 d[attr] = getattr(self, attr)
             elif not is_msgpack:
-                 d[attr] = getattr(self, attr)
+                d[attr] = field.get_prep_value(getattr(self, attr))
 
         if has_m2mfields:
             m2mfields = self.__class__._meta.many_to_many
@@ -414,8 +405,9 @@ class BaseModel(models.Model, SqlModelMixin):
                 return x.verbose_name
 
     @classmethod
-    def get_list_view_name(cls):
-        return '%s.%s.list' % (cls.get_app_name(), cls.lower_name)
+    def get_list_view_name(cls,model_class=None):
+        model_class = model_class or cls
+        return '%s.%s.list' % (model_class._meta.app_label, cls.get_lower_name(model_class))
 
     @classmethod
     def get_list_url(cls):
@@ -426,9 +418,9 @@ class BaseModel(models.Model, SqlModelMixin):
         return cls.get_lower_name()
 
     @classmethod
-    def get_lower_name(cls):
+    def get_lower_name(cls, model_class=None):
         new_lower_name_list = []
-        name_str = cls.__name__
+        name_str = model_class.__name__ if model_class else cls.__name__
         for i, c in enumerate(name_str):
             if i > 0 and c.isupper():
                 if name_str[i - 1].islower() or name_str[i + 1].islower():
@@ -454,17 +446,25 @@ class BaseModel(models.Model, SqlModelMixin):
     def get_fields_name_list(cls, ignore_keys=('id',)):
         return [f.get_attname() for f in cls.get_fields() if f.attname not in ignore_keys]
 
-    @classmethod
-    def get_fields(cls, has_private=False):
-        """返回模型的相关字段定义
-        """
+    @CachedClassAttribute
+    def fields(cls):
         opts = cls._meta
         from django.db.models.fields import Field as ModelField
         from itertools import chain
         sortable_private_fields = [f for f in opts.private_fields if isinstance(f, ModelField)]
-        return [f for f in sorted(chain(opts.concrete_fields, sortable_private_fields, opts.many_to_many)) if
+        return [f for f in sorted(chain(opts.concrete_fields, sortable_private_fields, opts.many_to_many))]
+
+    @classmethod
+    def get_fields(cls, has_private=False):
+        """返回模型的相关字段定义
+        """
+        return [f for f in cls.fields if
                 has_private or not f.name.startswith('_')]
 
+    @classmethod
+    def get_many_to_many_fileds(cls):
+        return cls._meta.many_to_many
+
     @CachedClassAttribute
     def fields_map(cls):
         return cls.get_fields_map()
@@ -479,6 +479,18 @@ class BaseModel(models.Model, SqlModelMixin):
         return cls.objects.prefetch_related(*[f.attname for f in cls._meta.many_to_many])
 
 
+class BaseModel(models.Model, BaseModelMixin):
+    id = models.BigAutoField(primary_key=True)
+    _version = models.IntegerField(_("版本"), default=0, null=False)
+    # auto_now_add = True    #创建时添加的时间  修改数据时，不会发生改变
+    create_datetime = models.DateTimeField(_("创建时间"), auto_now_add=True, blank=True)
+    update_datetime = models.DateTimeField(_("更新时间"), auto_now=True, blank=True)
+
+    class Meta:
+        abstract = True
+        ordering = ['id']
+
+
 class BaseNameModel(BaseModel):
     name = models.CharField(_('名称'), max_length=100, null=False, blank=False, validators=[LetterValidator],
                             unique=True)
@@ -553,6 +565,7 @@ class ObjectDictField(models.TextField):
 
 
 serializers.ModelSerializer.serializer_field_mapping[ObjectDictField] = DictField
+serializers.ModelSerializer.serializer_field_mapping[timezone_field.TimeZoneField] = CharField
 
 
 def validate_re(value, pattern='', err_msg=''):
