@@ -11,6 +11,7 @@ import logging
 import os
 import random
 import re
+import threading
 import time
 import traceback
 from collections import OrderedDict
@@ -38,6 +39,17 @@ def find_djapp_name(app_root_path):
             yield p
 
 
+class SingleInstance(object):
+    _instance = None
+    __instance_lock = threading.Lock()
+
+    def __new__(cls, *args, **kw):
+        with cls.__instance_lock:
+            if cls._instance is None:
+                cls._instance = object.__new__(cls, *args, **kw)
+            return cls._instance
+
+
 def sort_set_list(l):
     new_list = list(l)
     set_list = list(set(new_list))
@@ -78,6 +90,29 @@ def import_func(name):
 import_view = import_func
 import_module_attr = import_view
 
+import functools
+from inspect import isfunction
+
+
+class DecoratorsPartial(object):
+    """
+    语法糖使用装饰器能去掉括号()
+    """
+    def __init__(self, decorator_func, *args, **kwargs):
+        self.decorator_func = decorator_func
+        self.args = args
+        self.kwargs = kwargs
+
+    def __call__(self, *args, **kwargs):
+        if len(args) == 1 and isfunction(args[0]):
+            return self.decorator_func(*self.args, **self.kwargs)(args[0])
+        else:
+            @functools.wraps(self.decorator_func)
+            def decorator(func):
+                return self.decorator_func(*(args or self.args), **(kwargs or self.kwargs))(func)
+
+            return decorator
+
 
 class DateEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -88,14 +123,20 @@ class DateEncoder(json.JSONEncoder):
 
 class MyJsonEncoder(JSONEncoder):
     def default(self, obj):
+
         if isinstance(obj, models.Model):
             if hasattr(obj, 'to_dict'):
                 return obj.to_dict()
         elif isinstance(obj, QuerySet):
-            return [m.to_dict() if hasattr(m, 'to_dict') else m for m in obj  ]
+            return [m.to_dict() if hasattr(m, 'to_dict') else m for m in obj]
         elif isinstance(obj, serializers.Serializer):
             return obj.data
-        return super(MyJsonEncoder, self).default(obj)
+        if hasattr(obj, '__getstate__'):
+            return obj.__getstate__()
+        try:
+            return super().default(obj)
+        except TypeError as e:
+            return str(obj)
 
 
 def json_dumps(obj, *args, **kwargs):
@@ -261,6 +302,15 @@ def convert_to_datetime(input_value):
     raise TypeError('Unsupported input type: %s' % type(input_value))
 
 
+def is_valid_datetime(str):
+    '''判断是否是一个有效的日期字符串'''
+    try:
+        convert_to_datetime(str)
+        return True
+    except:
+        return False
+
+
 try:
     from hashlib import sha1
 except ImportError:
