@@ -5,7 +5,7 @@
 #
 # =========================================
 import functools
-import time
+import inspect
 import types
 from collections import OrderedDict
 
@@ -55,7 +55,7 @@ def is_notauth(view_func):
 
 def is_notcheck(view_func):
     """免权限检查"""
-    return hasattr(view_func, 'notcheck')
+    return is_notauth(view_func) or hasattr(view_func, 'notcheck')
 
 
 def json_response(func):
@@ -141,6 +141,7 @@ def model_search(request, model_objects, search=None, order=None, page_size=20,
     }
     return params
 
+
 def api_view(http_method_names=None, detail=False):
     """
     Decorator that converts a function-based view into an APIView subclass.
@@ -246,13 +247,23 @@ def action(methods=None, detail=False, url_path=None, url_name=None, **kwargs):
 
     return decorator
 
+def api_action_judge(*args,**kwargs):
 
-action_get = functools.partial(action, 'get')
-action_post = functools.partial(action, 'post')
-action_get_post = functools.partial(action, ['post', 'get'])
+    def decorator(func):
+        if inspect.getfullargspec(func).args[0] == 'self':
+            return action(*args,**kwargs)(func)
+        else:
+            return api_view(*args, **kwargs)(func)
+    return decorator
 
-api_get = functools.partial(api_view, 'get')
-api_post = functools.partial(api_view, 'post')
+from .utils import DecoratorsPartial
+
+action_get = DecoratorsPartial(api_action_judge, ['get'])
+action_post = DecoratorsPartial(api_action_judge, ['post'])
+action_get_post = DecoratorsPartial(api_action_judge, ['post', 'get'])
+
+api_get = DecoratorsPartial(api_action_judge, 'get')
+api_post = DecoratorsPartial(api_action_judge, 'post')
 
 from django.views.generic import View
 
@@ -404,7 +415,7 @@ class CurdViewSet(BaseViewSet):
         if not query_params.id:
             self.model_instance = self.model()
         else:
-            _queryset = self.model.objects
+            _queryset = self.get_queryset()
             try:
                 if queryset is not None:
                     _queryset = queryset
@@ -459,7 +470,7 @@ class CurdViewSet(BaseViewSet):
             model_instance._prefetched_objects_cache = {}
         return serializer, msg
 
-    def save(self, request: Request,*args, **kwargs):
+    def save(self, request: Request, *args, **kwargs):
         """
         保存
         """
@@ -501,7 +512,7 @@ class I18n(BaseViewSet):
         """
         return set_language(request)
 
-    @notcheck
+    @notauth
     @action('get')
     def js(self, request):
         """js语言切换,加载
